@@ -33,6 +33,9 @@ def nms(result_detection: [float],
     result_class = []
     final_bbox = []
     final_class_prob = []
+
+    array_shape = result_detection.shape
+    class_num = array_shape[2] - 5
     
     for boxes in result_detection:
         mask = boxes[:, 4] > confidence_threshold
@@ -44,7 +47,7 @@ def nms(result_detection: [float],
         boxes = np.concatenate((boxes[:, :5], classes, classes_prob), axis=-1)
 
         boxes_dict = dict()
-        for cls in range(16):
+        for cls in range(class_num):
             mask = (boxes[:, 5] == cls)
             mask_shape = mask.shape
                 
@@ -228,10 +231,10 @@ def resize_bboxes_based_img_size(bboxes: [[float]],
     """ 
     res = []         
     for i in bboxes:                      
-        x = int((bbox[0]/416)*img_shape[1])
-        y = int((bbox[1]/416)*img_shape[0])
-        w = int((bbox[2]/416)*img_shape[1])
-        h = int((bbox[3]/416)*img_shape[0])
+        x = int((i[0]/416)*img_shape[1])
+        y = int((i[1]/416)*img_shape[0])
+        w = int((i[2]/416)*img_shape[1])
+        h = int((i[3]/416)*img_shape[0])
         obj_prob = i[4]
         clss = i[5]
         clss_prob = i[6]
